@@ -4,6 +4,7 @@
  * Copyright 2005, 2006, 2007 Russ Allbery <rra@debian.org>
  * Copyright 2005 Andres Salomon <dilinger@debian.org>
  * Copyright 1999, 2000 Frank Cusack <fcusack@fcusack.com>
+ *
  * See LICENSE for licensing terms.
  */
 
@@ -17,7 +18,7 @@
 #include "internal.h"
 
 void
-pamk5_compat_free_data_contents(krb5_context c, krb5_data *data)
+pamk5_compat_free_data_contents(krb5_context c UNUSED, krb5_data *data)
 {
     krb5_data_free(data);
 }
